==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/GetPermissionPolicyResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.waf.model.primitives.PolicyString
import scala.jdk.CollectionConverters._
final case class GetPermissionPolicyResponse(
    policy: Option[PolicyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse = {
    import GetPermissionPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse
      .builder()
      .optionallyWith(
        policy.map(value => PolicyString.unwrap(value): java.lang.String)
      )(_.policy)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetPermissionPolicyResponse.ReadOnly =
    zio.aws.waf.model.GetPermissionPolicyResponse.wrap(buildAwsValue())
}
object GetPermissionPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetPermissionPolicyResponse =
      zio.aws.waf.model.GetPermissionPolicyResponse(policy.map(value => value))
    def policy: Option[PolicyString]
    def getPolicy: ZIO[Any, AwsError, PolicyString] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse
  ) extends zio.aws.waf.model.GetPermissionPolicyResponse.ReadOnly {
    override val policy: Option[PolicyString] = scala
      .Option(impl.policy())
      .map(value => zio.aws.waf.model.primitives.PolicyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse
  ): zio.aws.waf.model.GetPermissionPolicyResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-waf_2.13-5.19.8.4-sources.jar: zio/aws/waf/model/GetPermissionPolicyResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.waf.model.primitives.PolicyString
import scala.jdk.CollectionConverters._
final case class GetPermissionPolicyResponse(
    policy: Optional[PolicyString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse = {
    import GetPermissionPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse
      .builder()
      .optionallyWith(
        policy.map(value => PolicyString.unwrap(value): java.lang.String)
      )(_.policy)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetPermissionPolicyResponse.ReadOnly =
    zio.aws.waf.model.GetPermissionPolicyResponse.wrap(buildAwsValue())
}
object GetPermissionPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetPermissionPolicyResponse =
      zio.aws.waf.model.GetPermissionPolicyResponse(policy.map(value => value))
    def policy: Optional[PolicyString]
    def getPolicy: ZIO[Any, AwsError, PolicyString] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse
  ) extends zio.aws.waf.model.GetPermissionPolicyResponse.ReadOnly {
    override val policy: Optional[PolicyString] = zio.aws.core.internal
      .optionalFromNullable(impl.policy())
      .map(value => zio.aws.waf.model.primitives.PolicyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetPermissionPolicyResponse
  ): zio.aws.waf.model.GetPermissionPolicyResponse.ReadOnly = new Wrapper(impl)
}
